Draw bootstrap resamples for an RDS dataset, using
the algorithm described in the supporting online
material of Weir et al 2012 (see rds.boot.draw.chain() ).
rds.chain.boot.draws(chains, mm, dd, num.reps, keep.vars = NULL)A list of length num.reps; each entry in
the list has one bootstrap-resampled dataset
A list whose entries are the chains we want to resample
The mixing model
The degree distributions
The number of bootstrap resamples we want
If not NULL, then the names of variables
from the original dataset we want appended to each bootstrap
resampled dataset (default is NULL)